@@ -1,6 +1,5 @@
 from remotecv.image_processor import ImageProcessor
-from remotecv.result_store import ResultStore
-from remotecv.utils import config
+from remotecv.utils import config, logger
 
 class DetectTask:
     queue = "Detect"
@@ -8,7 +7,8 @@ class DetectTask:
 
     @classmethod
     def perform(clz, detection_type, image_path, key):
+        logger.info('Detecting %s for %s' % (detection_type, image_path))
         image_data = config.loader.load_sync(image_path)
         points = clz.processor.detect(detection_type, image_data)
-        result_store = ResultStore(clz.resq.redis)
+        result_store = config.store.ResultStore(config)
         result_store.store(key, points)
